pro get_orbit, objectname, orbit, suffix=suffix, dir=dir, mcent=mcent

  if (not keyword_set(suffix)) then suffix = '.aei'
  if (not keyword_set(dir)) then dir='.'
  if (not keyword_set(mcent)) then mcent=1.0 ; central mass in solar masses

  filename = dir + '/' + objectname + suffix
  readcol, filename, format='D,D,D,D,D,D,D,D', time, a, e, i, peri, node, M, mass

  degtorad, M
  degtorad, peri
  degtorad, i
  degtorad, node

  lambda = M+peri+node
  limrange, lambda

  pomega = peri+node
  limrange, pomega

  get_rf, a=a, e=e, M=M, f=f, r=r

  x = r*( cos(node)*cos(peri+f) - sin(node)*sin(peri+f)*cos(i) )
  y = r*( sin(node)*cos(peri+f) + cos(node)*sin(peri+f)*cos(i) )
  z = r*sin(peri+f)*sin(i)

  n = 2.0*!dpi*sqrt(mcent)/a^(3./2.)
  xorbdot = -n*a*sin(f)/sqrt(1.0-e^2)
  yorbdot = n*a*(e+cos(f))/sqrt(1.0-e^2)
  vx = cos(node)*(xorbdot*cos(peri) - yorbdot*sin(peri)) - sin(node)* ((xorbdot*sin(peri) + yorbdot*cos(peri))*cos(i)) ; AU/yr
  vy = sin(node)*(xorbdot*cos(peri) - yorbdot*sin(peri)) + cos(node)* ((xorbdot*sin(peri) + yorbdot*cos(peri))*cos(i)) ; AU/yr
  vz = (xorbdot*sin(peri) + yorbdot*cos(peri))*sin(i) ; AU/yr

  orbit = {rmc_orbstruct}
  orbit = replicate(orbit, n_elements(time))

  orbit.name = replicate(objectname, n_elements(time))
  orbit.mass = mass
  orbit.time = time
  orbit.a = a
  orbit.e = e
  orbit.i = i
  orbit.peri = peri
  orbit.node = node
  orbit.M = M
  orbit.r = r
  orbit.f = f
  orbit.lambda = lambda
  orbit.pomega = pomega
  orbit.x = x
  orbit.y = y
  orbit.z = z
  orbit.vx = vx
  orbit.vy = vy
  orbit.vz = vz

end
