pro rmc_orbstruct__define

;; This defines a structure that holds instantaneous
;; properties of an object's orbit, including osculating
;; elements, position, and velocity.

;; Our default setup generates orbital elements relative to the
;; central star (as opposed to the system's center of mass).

tmp = {rmc_orbstruct, $
          name: '',      $  ;; name of object
          mass: 0d,      $  ;; mass of object (solar masses)
          time: 0d,      $  ;; time at which these values are valid (yr)
          a: 0d,         $  ;; semi-major axis (AU)
          e: 0d,         $  ;; eccentricity
          i: 0d,         $  ;; inclination (radians)
          peri: 0d,      $  ;; argument of pericenter (radians)
          node: 0d,      $  ;; longitude of ascending node (radians)
          M: 0d,         $  ;; mean anomaly (radians)
          r: 0d,         $  ;; distance from the central body or center of mass (AU)
          f: 0d,         $  ;; true anomaly (radians)
          lambda: 0d,    $  ;; mean longitude (radians)
          pomega: 0d,    $  ;; longitude of pericenter (radians)
          x:  0d,        $  ;; cartesian position in x direction (AU)
          y:  0d,        $  ;; cartesian position in y direction (AU)
          z:  0d,        $  ;; cartesian position in z direction (AU)
          vx: 0d,        $  ;; cartesian velocity in x direction (AU/yr)
          vy: 0d,        $  ;; cartesian velocity in y direction (AU/yr)
          vz: 0d         $  ;; cartesian velocity in z direction (AU/yr)
         }

end
