function solve_kepler, M=M, e=e


 ; function for implementing Newton's method to fourth order
 ; to solve Kepler's Equation, M = E-esinE
 ; given M and e, the program returns E
 ;
 ; based on Danby Ch. 6
 ;
 ; adapted from my C code

  initial_guess = 0.85d0
  Delta = 1d-14  ; allowed error in solution

  k = initial_guess
  M = double(M)
  e = double(e)
 
  Meff = M - floor(M/(2.0*!dpi))*2.0*!dpi;  /* M mod 2pi */
  
  if (sin(Meff) ge 0) then sigma=1.0 else sigma=-1.0 ; /* sigma = sign(sinM) */
  x = Meff + sigma * k * e;  /* our first guess for E */

  count = 0; /* counts the number of iterations */

  esinx = e*sin(x);
  f = x - esinx - Meff; /* f = 0 when x = E */
  ;/* absolute value */
  while (((f gt 0) and (f gt Delta)) or ((f lt 0) and (f lt -Delta))) do begin
        esinx = e*sin(x);
        f = x - esinx - Meff; /* f = 0 when x = E */
        ecosx = e*cos(x);
        fp = 1.0 - ecosx;   /* first derivative of f */
        fpp = esinx;       /* second derivative of f */
        fppp = ecosx;      /* third derivative of f */
        dx = -f/fp;
        dx = -f/(fp + dx*fpp/2.0);
        dx = -f/(fp + dx*fpp/2.0 + dx*dx*fppp/6.0);
        x = x + dx;
        count = count + 1

        if (count gt 10) then begin
                print, "no convergence"
                break;
        endif
        ;/*printf("x: %f, dx: %f", x, dx);*/ /* watch progress */

 endwhile

  x = x - floor(x/(2.0*!dpi))*2.0*!dpi; /* in case it ends up outside of range */

  return, x ;  /* x is our desired value, E */

end
